@@ -11,9 +11,9 @@ bread <- function(x, ...)
   UseMethod("bread")
 }
 
-bread.lm <- bread.nls <- function(x, ...)
+bread.lm <- function(x, ...)
 {
-  sx <- summary(x)
+  sx <- summary.lm(x)
   return(sx$cov.unscaled * as.vector(sum(sx$df[1:2])))
 }
 
@@ -26,6 +26,12 @@ bread.glm <- function(x, ...)
   return(sx$cov.unscaled * as.vector(sum(sx$df[1:2])) * dispersion)
 }
 
+bread.nls <- function(x, ...)
+{
+  sx <- summary(x)
+  return(sx$cov.unscaled * as.vector(sum(sx$df[1:2])))
+}
+
 bread.survreg <- function(x, ...)
   length(x$linear.predictors) * x$var
 
